@@ -1,8 +1,8 @@
 import json
 
 import six
-
 from rebotics_sdk.providers.utils import hash_file, accept_file
+
 from .base import ReboticsBaseProvider, remote_service, PageResult
 
 
@@ -154,13 +154,12 @@ class RetailerProvider(ReboticsBaseProvider):
         params = {
             'page': page,
         }
-        if is_removed:
+        if is_removed is not None:
             assert isinstance(is_removed, bool)
             params['is_removed'] = is_removed
 
         return PageResult(self.session.get(
             product_id=product_id,
-            url=self.session.host,
             params=params
         ))
 
@@ -183,6 +182,15 @@ class RetailerProvider(ReboticsBaseProvider):
             'product_unique_id': upc
         })
 
+    @remote_service('/api/v4/products/search/')
+    def get_product_info_by_upc(self, upc_list):
+        if not all(upc.isdigit() for upc in upc_list):
+            raise ValueError("Supplied non numeric code in list")
+
+        return PageResult(self.session.post(json={
+            'plu': upc_list
+        }))
+
     @remote_service('/api/v4/product/previews/{preview_id}/add_feature_reference/')
     def set_product_preview_feature_id(self, preview_id, feature_id, facenet):
         return self.session.post(
@@ -353,3 +361,22 @@ class RetailerProvider(ReboticsBaseProvider):
                 'section': section,
             }
         )
+
+    @remote_service('api/v1/master-data/file-upload/')
+    def v1_upload_file(self, file):
+        return self.session.post(
+            data={
+                'description': 'preview upload from SDK',
+            },
+            files={
+                'file': file
+            }
+        )
+
+    @remote_service('api/v1/master-data/products/{product_id}/images/')
+    def v1_upload_preview(self, product_id, image_id):
+        return self.session.post(
+            product_id=product_id,
+            json={
+                'image': image_id
+            }, content_type='application/json')
